@@ -1,7 +1,7 @@
 from pydantic import BaseModel
 from typing import Optional, List
 from enum import IntEnum
-from import_models import ProductGroupJsonDTO, FADNProductJsonDTO, PolicyJsonDTO
+from agricore_sp_models.import_models import ProductGroupJsonDTO, FADNProductJsonDTO, PolicyJsonDTO
 
 class OrganicProductionType(IntEnum):
     Conventional = 0
